==> haskell-yesod-static-1.6.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.6.0
id: yesod-static-1.6.0-CRf5Y7BlutC1gqgCi2ZUZ1
key: yesod-static-1.6.0-CRf5Y7BlutC1gqgCi2ZUZ1
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
abi: 28717f6d7f0e19d7c624e494d27491be
exposed: True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-static-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-static-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-static-1.6.0
hs-libraries: HSyesod-static-1.6.0-CRf5Y7BlutC1gqgCi2ZUZ1
depends:
    base-4.11.1.0 containers-0.5.11.0
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    yesod-core-1.6.5-LcrqBqtPCss8l2PlKPds8d
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    template-haskell-2.13.0.0 directory-1.3.1.5 transformers-0.5.5.0
    wai-app-static-3.1.6.2-E2SR1qAm0wR2HTnhbEeY0l
    wai-3.2.1.2-LKLIDbQRtqgEPtmIr3MYaf text-1.2.3.0
    file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK
    http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    conduit-1.3.0.3-5ZsOzo28L26JRNfLzW387B
    cryptonite-conduit-0.2.2-A0XMl0jsd1C3jT7nTytxxo
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4
    hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8 filepath-1.4.2
    resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y process-1.6.3.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    css-text-0.1.3.0-4xpumRW9EcZ3GJ3XASFiay
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             yesod-core-1.6.5-LcrqBqtPCss8l2PlKPds8d=7066bff53132af87d0e0a2cf2e664220
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-app-static-3.1.6.2-E2SR1qAm0wR2HTnhbEeY0l=509fe8abf20f0174aa74e953c7eb8a99
             wai-3.2.1.2-LKLIDbQRtqgEPtmIr3MYaf=8fef4b7f1f92cc00d34b31969465d409
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK=480b24a4b596c19b5b43e12ca8596adb
             http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX=c36ea90c1caed733a7293143960ab603
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             conduit-1.3.0.3-5ZsOzo28L26JRNfLzW387B=4f322a960d59e7167ba56eb1269967d6
             cryptonite-conduit-0.2.2-A0XMl0jsd1C3jT7nTytxxo=686d5aca37afb31ff70249cb397620e2
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             mime-types-0.1.0.7-LUz1fzcauM82P0JAicK9l4=4b037b274a675339ca568d385933d1c6
             hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8=d8daa2345d1d457cd82a785d00e0efbe
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8=ac43be68d39189ee09e7e4402242c3d2
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             css-text-0.1.3.0-4xpumRW9EcZ3GJ3XASFiay=c58fdad56b43f2dc1c379c6ffa6cab67
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.0-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.6.0
id: yesod-static-1.6.0-Ckn98JXcnlw5tEEDRbJpBg
key: yesod-static-1.6.0-Ckn98JXcnlw5tEEDRbJpBg
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
abi: 9364fbd705fb40f06bd6d65f79d1d08d
exposed: True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-static-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-static-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-static-1.6.0
hs-libraries: HSyesod-static-1.6.0-Ckn98JXcnlw5tEEDRbJpBg
depends:
    base-4.11.1.0 containers-0.5.11.0
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu
    yesod-core-1.6.5-AJVrH6x2Yeq8D0Zh9VYpU1
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    template-haskell-2.13.0.0 directory-1.3.1.5 transformers-0.5.5.0
    wai-app-static-3.1.6.2-CC4jVlgJmosFVTjb4bUVaO
    wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw text-1.2.3.0
    file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK
    http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    conduit-1.3.0.3-LmObnhjlBlXKWT3aaj2Pgm
    cryptonite-conduit-0.2.2-GDGIvnTND186f0fz4lo1IR
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
    hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8 filepath-1.4.2
    resourcet-1.2.1-DyrMduhw6NcBH9776LSX58
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y process-1.6.3.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    css-text-0.1.3.0-27Ryu6Ji4q7Eld6aTTOsD
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             yesod-core-1.6.5-AJVrH6x2Yeq8D0Zh9VYpU1=ba854431e2fb189a28fbea3865ee5415
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-app-static-3.1.6.2-CC4jVlgJmosFVTjb4bUVaO=8c4bcb826a491a734c91383d21009cbc
             wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw=4dcfd1f19878874b7a3f1edbd12d60e9
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK=480b24a4b596c19b5b43e12ca8596adb
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             conduit-1.3.0.3-LmObnhjlBlXKWT3aaj2Pgm=535591a208ecba6a439708afbfef5621
             cryptonite-conduit-0.2.2-GDGIvnTND186f0fz4lo1IR=f94e2b0f3f17ec2cf18c4c114de3cb44
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=6260d9a08ca2b5415d71a41584891d7f
             hjsmin-0.2.0.2-AN8aCHidyxO8ckJRbczjO8=d8daa2345d1d457cd82a785d00e0efbe
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             resourcet-1.2.1-DyrMduhw6NcBH9776LSX58=5ef1111b0548768da5656735a567125c
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq=07053c5359c7530f0cb8534ff020b021
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             css-text-0.1.3.0-27Ryu6Ji4q7Eld6aTTOsD=e62797d8201d385feaf263fa4dc5df65
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
